<?php

// Start of apc v.3.1.3p1

/**
 * (PECL apc &gt;= 2.0.0)<br/>
 * Retrieves cached information from APC's data store
 * @link http://php.net/manual/en/function.apc-cache-info.php
 * @param string $cache_type [optional] <p>
 * If cache_type is "user",
 * information about the user cache will be returned.
 * </p>
 * <p>
 * If cache_type is "filehits",
 * information about which files have been served from the bytecode cache
 * for the current request will be returned. This feature must be enabled at
 * compile time using --enable-filehits.
 * </p>
 * <p>
 * If an invalid or no cache_type is specified, information about
 * the system cache (cached files) will be returned.
 * </p>
 * @param bool $limited [optional] <p>
 * If limited is true, the
 * return value will exclude the individual list of cache entries. This
 * is useful when trying to optimize calls for statistics gathering.
 * </p>
 * @return array Array of cached data (and meta-data)&return.falseforfailure;
 */
function apc_cache_info ($cache_type = null, $limited = false) {}

/**
 * (PECL apc &gt;= 2.0.0)<br/>
 * Clears the APC cache
 * @link http://php.net/manual/en/function.apc-clear-cache.php
 * @param string $cache_type [optional] <p>
 * If cache_type is "user", the
 * user cache will be cleared; otherwise, the system cache (cached files)
 * will be cleared.
 * </p>
 * @return bool Returns true on success or false on failure.
 */
function apc_clear_cache ($cache_type = null) {}

/**
 * (PECL apc &gt;= 2.0.0)<br/>
 * Retrieves APC's Shared Memory Allocation information
 * @link http://php.net/manual/en/function.apc-sma-info.php
 * @param bool $limited [optional] <p>
 * When set to false (default) apc_sma_info will
 * return a detailed information about each segment.
 * </p>
 * @return array Array of Shared Memory Allocation data; false on failure.
 */
function apc_sma_info ($limited = false) {}

/**
 * (PECL apc &gt;= 3.0.0)<br/>
 * Cache a variable in the data store
 * @link http://php.net/manual/en/function.apc-store.php
 * @param string $key <p>
 * Store the variable using this name. keys are
 * cache-unique, so storing a second value with the same
 * key will overwrite the original value.
 * </p>
 * @param mixed $var <p>
 * The variable to store
 * </p>
 * @param int $ttl [optional] <p>
 * Time To Live; store var in the cache for
 * ttl seconds. After the
 * ttl has passed, the stored variable will be
 * expunged from the cache (on the next request). If no ttl
 * is supplied (or if the ttl is
 * 0), the value will persist until it is removed from
 * the cache manually, or otherwise fails to exist in the cache (clear,
 * restart, etc.).
 * </p>
 * @return bool Returns true on success or false on failure.
 * Second syntax returns array with error keys.
 */
function apc_store ($key, $var, $ttl = 0) {}

/**
 * (PECL apc &gt;= 3.0.0)<br/>
 * Fetch a stored variable from the cache
 * @link http://php.net/manual/en/function.apc-fetch.php
 * @param mixed $key <p>
 * The key used to store the value (with
 * apc_store). If an array is passed then each
 * element is fetched and returned.
 * </p>
 * @param bool $success [optional] <p>
 * Set to true in success and false in failure.
 * </p>
 * @return mixed The stored variable or array of variables on success; false on failure
 */
function apc_fetch ($key, &$success = null) {}

/**
 * (PECL apc &gt;= 3.0.0)<br/>
 * Removes a stored variable from the cache
 * @link http://php.net/manual/en/function.apc-delete.php
 * @param string $key <p>
 * The key used to store the value (with
 * apc_store).
 * </p>
 * @return mixed Returns true on success or false on failure.
 */
function apc_delete ($key) {}

/**
 * (PECL apc &gt;= 3.1.1)<br/>
 * Deletes files from the opcode cache
 * @link http://php.net/manual/en/function.apc-delete-file.php
 * @param mixed $keys <p>
 * The files to be deleted. Accepts a string,
 * array of strings, or an APCIterator
 * object.
 * </p>
 * @return mixed Returns true on success or false on failure.
 * Or if keys is an array, then
 * an empty array is returned on success, or an array of failed files
 * is returned.
 */
function apc_delete_file ($keys) {}

/**
 * (PECL apc &gt;= 3.0.0)<br/>
 * Defines a set of constants for retrieval and mass-definition
 * @link http://php.net/manual/en/function.apc-define-constants.php
 * @param string $key <p>
 * The key serves as the name of the constant set
 * being stored. This key is used to retrieve the
 * stored constants in apc_load_constants.
 * </p>
 * @param array $constants <p>
 * An associative array of constant_name => value
 * pairs. The constant_name must follow the normal
 * constant naming rules.
 * value must evaluate to a scalar value.
 * </p>
 * @param bool $case_sensitive [optional] <p>
 * The default behaviour for constants is to be declared case-sensitive;
 * i.e. CONSTANT and Constant
 * represent different values. If this parameter evaluates to false the
 * constants will be declared as case-insensitive symbols.
 * </p>
 * @return bool Returns true on success or false on failure.
 */
function apc_define_constants ($key, array $constants, $case_sensitive = true) {}

/**
 * (PECL apc &gt;= 3.0.0)<br/>
 * Loads a set of constants from the cache
 * @link http://php.net/manual/en/function.apc-load-constants.php
 * @param string $key <p>
 * The name of the constant set (that was stored with
 * apc_define_constants) to be retrieved.
 * </p>
 * @param bool $case_sensitive [optional] <p>
 * The default behaviour for constants is to be declared case-sensitive;
 * i.e. CONSTANT and Constant
 * represent different values. If this parameter evaluates to false the
 * constants will be declared as case-insensitive symbols.
 * </p>
 * @return bool Returns true on success or false on failure.
 */
function apc_load_constants ($key, $case_sensitive = true) {}

/**
 * (PECL apc &gt;= 3.0.13)<br/>
 * Stores a file in the bytecode cache, bypassing all filters.
 * @link http://php.net/manual/en/function.apc-compile-file.php
 * @param string $filename <p>
 * Full or relative path to a PHP file that will be compiled and stored in
 * the bytecode cache.
 * </p>
 * @param bool $atomic [optional]
 * @return mixed Returns true on success or false on failure.
 */
function apc_compile_file ($filename, $atomic = true) {}

/**
 * (PECL apc &gt;= 3.0.13)<br/>
 * Cache a variable in the data store
 * @link http://php.net/manual/en/function.apc-add.php
 * @param string $key <p>
 * Store the variable using this name. keys are
 * cache-unique, so attempting to use apc_add to
 * store data with a key that already exists will not overwrite the
 * existing data, and will instead return false. (This is the only
 * difference between apc_add and
 * apc_store.)
 * </p>
 * @param mixed $var [optional] <p>
 * The variable to store
 * </p>
 * @param int $ttl [optional] <p>
 * Time To Live; store var in the cache for
 * ttl seconds. After the
 * ttl has passed, the stored variable will be
 * expunged from the cache (on the next request). If no ttl
 * is supplied (or if the ttl is
 * 0), the value will persist until it is removed from
 * the cache manually, or otherwise fails to exist in the cache (clear,
 * restart, etc.).
 * </p>
 * @return bool Returns true on success or false on failure.
 * Second syntax returns array with error keys.
 */
function apc_add ($key, $var = null, $ttl = 0) {}

/**
 * (PECL apc &gt;= 3.1.1)<br/>
 * Increase a stored number
 * @link http://php.net/manual/en/function.apc-inc.php
 * @param string $key <p>
 * The key of the value being increased.
 * </p>
 * @param int $step [optional] <p>
 * The step, or value to increase.
 * </p>
 * @param bool $success [optional] <p>
 * Optionally pass the success or fail boolean value to
 * this referenced variable.
 * </p>
 * @return int the current value of key's value on success,
 * &return.falseforfailure;
 */
function apc_inc ($key, $step = 1, &$success = null) {}

/**
 * (PECL apc &gt;= 3.1.1)<br/>
 * Decrease a stored number
 * @link http://php.net/manual/en/function.apc-dec.php
 * @param string $key <p>
 * The key of the value being decreased.
 * </p>
 * @param int $step [optional] <p>
 * The step, or value to decrease.
 * </p>
 * @param bool $success [optional] <p>
 * Optionally pass the success or fail boolean value to
 * this referenced variable.
 * </p>
 * @return int the current value of key's value on success,
 * &return.falseforfailure;
 */
function apc_dec ($key, $step = 1, &$success = null) {}

/**
 * (PECL apc &gt;= 3.1.1)<br/>
 * Updates an old value with a new value
 * @link http://php.net/manual/en/function.apc-cas.php
 * @param string $key <p>
 * The key of the value being updated.
 * </p>
 * @param int $old <p>
 * The old value (the value currently stored).
 * </p>
 * @param int $new <p>
 * The new value to update to.
 * </p>
 * @return bool Returns true on success or false on failure.
 */
function apc_cas ($key, $old, $new) {}

/**
 * (PECL apc &gt;= 3.1.4)<br/>
 * Get a binary dump of the given files and user variables
 * @link http://php.net/manual/en/function.apc-bin-dump.php
 * @param array $files [optional] <p>
 * The files. Passing in null signals a dump of every entry, while
 * passing in array will dump nothing.
 * </p>
 * @param array $user_vars [optional] <p>
 * The user vars. Passing in null signals a dump of every entry, while
 * passing in array will dump nothing.
 * </p>
 * @return string a binary dump of the given files and user variables from the APC cache,
 * false if APC is not enabled, or null if an unknown error is encountered.
 */
function apc_bin_dump (array $files = null, array $user_vars = null) {}

/**
 * (PECL apc &gt;= 3.1.4)<br/>
 * Load a binary dump into the APC file/user cache
 * @link http://php.net/manual/en/function.apc-bin-load.php
 * @param string $data <p>
 * The binary dump being loaded, likely from
 * apc_bin_dump.
 * </p>
 * @param int $flags [optional] <p>
 * Either APC_BIN_VERIFY_CRC32, APC_BIN_VERIFY_MD5,
 * or both.
 * </p>
 * @return bool true if the binary dump data was loaded
 * with success, otherwise false is returned. false is returned if APC
 * is not enabled, or if the data is not a valid APC
 * binary dump (e.g., unexpected size).
 */
function apc_bin_load ($data, $flags = 0) {}

/**
 * (PECL apc &gt;= 3.1.4)<br/>
 * Output a binary dump of cached files and user variables to a file
 * @link http://php.net/manual/en/function.apc-bin-dumpfile.php
 * @param array $files <p>
 * The file names being dumped.
 * </p>
 * @param array $user_vars <p>
 * The user variables being dumped.
 * </p>
 * @param string $filename <p>
 * The filename where the dump is being saved.
 * </p>
 * @param int $flags [optional] <p>
 * Flags passed to the filename stream. See the
 * file_put_contents documentation for details.
 * </p>
 * @param resource $context [optional] <p>
 * The context passed to the filename stream. See the
 * file_put_contents documentation for details.
 * </p>
 * @return int The number of bytes written to the file, otherwise
 * false if APC is not enabled, filename is an invalid file name,
 * filename can't be opened, the file dump can't be completed
 * (e.g., the hard drive is out of disk space), or an unknown error was encountered.
 */
function apc_bin_dumpfile (array $files, array $user_vars, $filename, $flags = 0, $context = null) {}

/**
 * (PECL apc &gt;= 3.1.4)<br/>
 * Load a binary dump from a file into the APC file/user cache
 * @link http://php.net/manual/en/function.apc-bin-loadfile.php
 * @param string $filename <p>
 * The file name containing the dump, likely from
 * apc_bin_dumpfile.
 * </p>
 * @param resource $context [optional] <p>
 * The files context.
 * </p>
 * @param int $flags [optional] <p>
 * Either APC_BIN_VERIFY_CRC32, APC_BIN_VERIFY_MD5,
 * or both.
 * </p>
 * @return bool true on success, otherwise false Reasons it may return false include
 * APC is not enabled, filename is an invalid file name or empty,
 * filename can't be opened, the file dump can't be completed, or
 * if the data is not a valid APC binary dump (e.g., unexpected
 * size).
 */
function apc_bin_loadfile ($filename, $context = null, $flags = null) {}

// End of apc v.3.1.3p1
?>
